#!/usr/bin/perl
# extracting tmx file from COPPA
# PLUS selection biomedical data (codes A61, C12N and C12P)
# usage: ./coppa.pl path-to-gzipped-tmx-files
#
# Outputs:
# coppa-medical.fr-en.tsv -- in-domain sections of the corpus
# coppa-other.fr-en.tsv -- out-of-domain sections of the corpus

use warnings;
use encoding 'utf-8';

die "usage: ./coppa.perl path-to-gzipped-tmx-files" if ! @ARGV;
my $path = $ARGV[0];
open(my $IN, "zcat " . join(" ", glob("$path/PCT*.en-fr.tmx.gz")) . " |");
binmode $IN, ":utf8";

open(my $OUTIN,">:utf8","coppa-medical.fr-en.tsv") or die "Cannot open coppa-medical.fr-en.tsv: $!";
open(my $OUT, ">:utf8","coppa-other.fr-en.tsv") or die "Cannot open coppa-other.fr-en.tsv: $!";

my $hdl;
my ($en, $fr);
while(<$IN>) {
  chomp(my $line = $_);
  if ($line =~ m/^\s*<prop type="Att::IPC">/) {
    $hdl = ($line =~ m/(A61|C12N|C12P)/ ? $OUTIN : $OUT);
  } elsif ($line =~ m/<tuv xml:lang=\"(..)\"><seg>(.+)<\/seg><\/tuv>/) {
    if (lc $1 eq "fr") {
      $fr = $2;
    } else {
      $en = $2;
    }
  }
  if ($fr && $en) {
    print $hdl "$fr\t$en\n";
    undef $fr;
    undef $en;
  }
}
