#!/usr/bin/perl
# processing drugBank
# selection of tags with textual content
# usage: drugbank.pl < drugbank.xml > drugbank.txt

use warnings;
use encoding 'utf-8';
my $line;
my %duplicates;
            
while(<STDIN>) {
  if   (/<drug(?:bank-id)?>/) { # following lines should be meaningful
    tag_posl("drug(?:bank-id)?","name");   
    tag_posl("name","description");
  }
  elsif (/<indication>/) {
    tag_single("indication",$_); }
  elsif (/<pharmacology>/) {
    tag_single("pharmacology",$_); }
  elsif (/<mechanism-of-action>/) {
    tag_single("mechanism-of-action",$_); }
  elsif (/<toxicity>/) {
    tag_single("toxicity",$_); }
  elsif (/<biotransformation>/) {
    tag_single("biotransformation",$_); }
  elsif (/<absorption>/) {
    tag_single("absorption",$_); }
  elsif (/<route-of-elimination>/) {
    tag_single("route-of-elimination",$_); }
}

sub tag_posl {
# reading one line and checking the order of lines
  my $tag0 = shift;
  my $tag1 = shift;
  my $line = <STDIN>;
  if ($line =~ /<$tag1>/)  { 
    tag_single($tag1,$line);
  }
  else {print "$_:!!! $tag1 does not follow $tag0\n";}
}  

sub tag_single {
# extracting content of a tag, even with newlines
  my $tag  = shift;
  my $line = shift;
  if (($text) = $line =~/<$tag>(.*)<\/$tag>/) { # unempty content
  }
  elsif (($text) = $line =~/<$tag>(.+)(&#xD;)?$/) { # unempty content not finished
    while ($line = <STDIN>) {
      if ($line =~ /(.*)<\/$tag>$/) {
         $text .= $1;
         print $text, "\n";
        last;
      }
      elsif ($line =~ /(.+)(&#xD;)?$/) { # continuation
         $text .= $1." ";
      }
    }
  }
  tisk();
}   

sub tisk {
# checking duplicates and print
  unless($duplicates{$text}) {
    print $text;
    if($text) {print "\n";}
    $duplicates{$text} = 1;
  }
}
