#!/bin/bash

# usage: pattr.sh path-to-corpus src-lang tgt-lang
#
# Creates monolingual files divided into in- and out-of-domain data
# in the directory where the script is run.
#
# Curently supported languages are en de (English-German) and fr en (French-English)
#
# Files created:
#
# .en, .de/.fr monolingual files for the non-parallel section descriptions 

path=$1
if [ ! -d "$path" ] ; then
  echo "Directory not exists" 1>&2	
  echo "Usage: pattr.sh path-to-corpus language-pair" 1>&2
  exit 1
fi

src=$2
tgt=$3
pair=$src-$tgt
if  [ "$pair" != "en-fr" ] && [ "$pair" != "de-en" ] ; then
  echo "Set languages to \"en\" \"de\" or \"fr\" \"en\"" 1>&2	
  echo "Usage: pattr.sh path-to-corpus language-pair" 1>&2
  exit 1
fi

# section Description is *not parallel*, produce individual
# files for each language (divided into in/out-domains portions)
for lang in $src $tgt ; do
  paste $path/description/pattr.$pair.description.$lang \
    $path/description/pattr.$pair.description.$lang.meta \
    | egrep '(A61|C12N|C12P)[^   ]*$' \
    | cut -f1 > pattr-medical.description.$pair.$lang

  paste $path/description/pattr.$pair.description.$lang \
    $path/description/pattr.$pair.description.$lang.meta \
    | egrep -v '(A61|C12N|C12P)[^   ]*$' \
    | cut -f1 > pattr-other.description.$pair.$lang
done
