#!/usr/bin/env perl
#
# Extracting monolingual concept description from the UMLS database
#
# Usage: ./umls-monolingual.pl file1 [file2...] 
#
# The script creates four files: "umls.en", "umls.cs","umls.de", and "umls.fr"
# with description extracted from the UML metathesaurus.
#
# The default UMLS file for this kind of data is MRDEF.RRF.gz.

use strict;
use warnings;
use utf8;

binmode(STDOUT, ':utf8'); 

# initialize data structures
my $USAGE = 'Usage: ./umls-monolingual.pl MRDEF.RRF.gz';

if (!@ARGV){
    die($USAGE);
}

my %codes = (
    'ALT' => "en",
    'AOT' => "en",
    'CCC' => "en",
    'CDT' => "en",
    'CHV' => "en",
    'CSP' => "en",
    'FMA' => "en",
    'GO' => "en",
    'HL7V3.0' => "en",
    'ICF' => "en",
    'ICF-CY' => "en",
    'MDR' => "en",
    'MDRCZE' => "cs",
    'MDRDUT' => "",
    'MDRFRE' => "fr",
    'MDRGER' => "de",
    'MDRHUN' => "",
    'MDRITA' => "",
    'MDRJPN' => "",
    'MDRPOR' => "",
    'MDRSPA' => "",
    'MEDLINEPLUS' => "en",
    'MSH' => "en",
    'MSHCZE' => "cs",
    'MSHFRE' => "fr",
    'MSHSCR' => "",
    'NAN' => "en",
    'NCI' => "en",
    'NDFRT' => "en",
    'NIC' => "en",
    'NOC' => "en",
    'OMS' => "en",
    'PDQ' => "en",
    'PNDS' => "en",
    'PSY' => "en",
    'SCTSPA' => "",
    'SNOMEDCT_US' => "en",
    'SOP' => "en",
    'SPN' => "en",
    'UMD' => "en",
    'UWDA' => "en"
);

# (main)
# process input files
open(EN,">umls.en");
binmode(EN,':utf8');
open(FR,">umls.fr");
binmode(FR,':utf8');
open(DE,">umls.de");
binmode(DE,':utf8');
open(CS,">umls.cs");
binmode(CS,':utf8');

my %fhs = (
  "en" => *EN,
  "fr" => *FR,
  "de" => *DE,
  "cs" => *CS
);

foreach my $file (@ARGV){
    my $fh;

    if ($file =~ /\.gz$/){
        open($fh, 'gunzip -c "' . $file . '" |') or die('Cannot open:' . $file);
        binmode($fh, ':utf8');
    }
    else {
        open($fh, '<:utf8', $file) or die('Cannot open:' . $file);
    }

    while (my $line = <$fh>){
        #my ($text) = ($line =~ /^(?:[^\|]*\|){5}([^\|]*)\|/);
        my @fields = split /\|/, $line;
        my $lang = $codes{$fields[4]};
        if ($lang) {
          my $out_fh = $fhs{$lang};
          print $out_fh $fields[5], "\n";
        }
    }
}
